@@ -1,5 +1,5 @@
 /*
-  $Id: gtkmap.c,v 1.1 1999/10/25 14:07:07 issei Exp issei $
+  $Id: gtkmap.c,v 1.3 1999/12/01 03:51:06 issei Exp issei $
  */
 
 #include <sys/types.h>
@@ -227,13 +227,10 @@ nh_set_map_visual(int mode)
 	if(saved_vis != 0)
 	    gdk_image_destroy(tile_image);
 	if(mode == 0){
-/*
-  I guess 'W' is widest character in set of font.
-  Yes, I know this coding is too dirty. but it seems there 
-  are no way to obtain maximum width of set of font with GDK.
-  If anyone know good way to obtain, tell me please.
- */
-	    c_width = gdk_string_width(map_font, "W");
+	    if(map_font->type != GDK_FONT_FONT)
+		panic("Bad font");
+
+	    c_width = ((XFontStruct *)GDK_FONT_XFONT(map_font))->max_bounds.width;
 	    c_height = map_font->ascent + map_font->descent;
 	    c_3dwidth = c_width;
 	    c_3dheight = c_height;
@@ -294,7 +291,9 @@ nh_get_map_visual(void)
 static int
 fix_tile(int tile)
 {
-/*    int orgtile = tile;*/
+#ifndef JNETHACK
+    int orgtile = tile;
+#endif
 
     if(map_visual == 0 || map_visual == 1)
 	return tile;
@@ -507,7 +506,7 @@ nh_map_destroy()
 GtkWidget *
 nh_map_new(GtkWidget *w)
 {
-    int i, n;
+    int i/*, n*/;
     int width, height;
     int shmflg;
 
@@ -552,12 +551,13 @@ nh_map_new(GtkWidget *w)
     xshm_init(display);
     shmflg = xshm_map_init(NH_MAP_MAX_WIDTH, NH_MAP_MAX_HEIGHT);
 
+#if 0
 /*
   load font
 
   GTK nethack automaticaly set font path to HACKDIR
   if server and client are running at same host.
- */
+  */
     if(shmflg){
 	char **path;
 	char **new_path;
@@ -576,10 +576,11 @@ nh_map_new(GtkWidget *w)
 	XSetFontPath(display, new_path, n+1);
     NextStep:
     }
+#endif
 
     map_font = gdk_font_load(NH_FONT);
     if(!map_font){
-	fprintf(stderr, "warning: cannot load %s. try to load %s", NH_FONT, NH_FONT2);
+/*	fprintf(stderr, "warning: cannot load %s. try to load %s", NH_FONT, NH_FONT2);*/
 	map_font = gdk_font_load(NH_FONT2);
     }
 
@@ -845,7 +846,11 @@ nh_map_print_glyph_traditional(XCHAR_P x, XCHAR_P y, struct tilemap *tmap, GdkRe
 	map_color_gc[color],
 	x * c_width, y * c_height, &ch, 1);
     
-    if(glyph_is_pet(glyph) && iflags.hilite_pet){
+    if(glyph_is_pet(glyph)
+#ifdef TEXTCOLOR
+	&& iflags.hilite_pet
+#endif
+	){
 	gdk_draw_rectangle(
 	    map_pixmap,
 	    map_color_gc[MAP_RED],
@@ -900,7 +905,11 @@ nh_map_print_glyph_tmp(struct tilemap *tmap, int ofsx, int ofsy, int flag)
 	x_tile_tmp_draw(bgsrc_x, bgsrc_y, ofsx, ofsy);
     }
 
-    if(glyph_is_pet(glyph) && iflags.hilite_pet){
+    if(glyph_is_pet(glyph)
+#ifdef TEXTCOLOR
+	&& iflags.hilite_pet
+#endif
+	){
 	x_tile_tmp_draw_rectangle(ofsx, ofsy, nh_color[MAP_RED].pixel);
     }
 }
